@@ -41,6 +41,7 @@ import (
 	"k8s.io/kops/pkg/diff"
 	"k8s.io/kops/pkg/featureflag"
 	"k8s.io/kops/pkg/jsonutils"
+	"k8s.io/kops/pkg/model/iam"
 	"k8s.io/kops/pkg/pki"
 	"k8s.io/kops/pkg/testutils"
 	"k8s.io/kops/pkg/testutils/golden"
@@ -344,6 +345,14 @@ func TestMinimalGp3(t *testing.T) {
 	newIntegrationTest("minimal.example.com", "minimal-gp3").runTestCloudformation(t)
 }
 
+// TestMinimal runs the test on a minimum configuration, similar to kops create cluster minimal.example.com --zones us-west-1a
+func TestMinimalLongClusterName(t *testing.T) {
+	newIntegrationTest("this.is.truly.a.really.really.long.cluster-name.minimal.example.com", "minimal-longclustername").
+		withAddons(dnsControllerAddon).
+		runTestTerraformAWS(t)
+	newIntegrationTest("this.is.truly.a.really.really.long.cluster-name.minimal.example.com", "minimal-longclustername").runTestCloudformation(t)
+}
+
 // TestExistingIAMCloudformation runs the test with existing IAM instance profiles, similar to kops create cluster minimal.example.com --zones us-west-1a
 func TestExistingIAMCloudformation(t *testing.T) {
 	lifecycleOverrides := []string{"IAMRole=ExistsAndWarnIfChanges", "IAMRolePolicy=ExistsAndWarnIfChanges", "IAMInstanceProfileRole=ExistsAndWarnIfChanges"}
@@ -558,6 +567,30 @@ func TestManyAddonsCCMIRSA(t *testing.T) {
 		runTestTerraformAWS(t)
 }
 
+func TestManyAddonsCCMIRSA23(t *testing.T) {
+	newIntegrationTest("minimal.example.com", "many-addons-ccm-irsa23").
+		withOIDCDiscovery().
+		withServiceAccountRole("dns-controller.kube-system", true).
+		withServiceAccountRole("aws-load-balancer-controller.kube-system", true).
+		withServiceAccountRole("aws-cloud-controller-manager.kube-system", true).
+		withServiceAccountRole("cluster-autoscaler.kube-system", true).
+		withServiceAccountRole("ebs-csi-controller-sa.kube-system", true).
+		withServiceAccountRole("aws-node-termination-handler.kube-system", true).
+		withAddons(
+			"aws-ebs-csi-driver.addons.k8s.io-k8s-1.17",
+			"aws-load-balancer-controller.addons.k8s.io-k8s-1.19",
+			"certmanager.io-k8s-1.16",
+			"cluster-autoscaler.addons.k8s.io-k8s-1.15",
+			"networking.amazon-vpc-routed-eni-k8s-1.16",
+			"node-termination-handler.aws-k8s-1.11",
+			"snapshot-controller.addons.k8s.io-k8s-1.20",
+			"aws-cloud-controller.addons.k8s.io-k8s-1.18",
+			leaderElectionAddon,
+			dnsControllerAddon,
+		).
+		runTestTerraformAWS(t)
+}
+
 func TestCCM(t *testing.T) {
 	newIntegrationTest("minimal.example.com", "many-addons-ccm").
 		withAddons(
@@ -1090,6 +1123,9 @@ func (i *integrationTest) runTestTerraformAWS(t *testing.T) {
 		expectedFilenames = append(expectedFilenames, "aws_key_pair_kubernetes."+i.clusterName+"-c4a6ed9aa889b9e2c39cd663eb9c7157_public_key")
 	}
 
+	masterRole := awsup.TruncateString("masters."+i.clusterName, awsup.TruncateStringOptions{MaxLength: iam.MaxLengthIAMRoleName, AlwaysAddHash: false})
+	nodeRole := awsup.TruncateString("nodes."+i.clusterName, awsup.TruncateStringOptions{MaxLength: iam.MaxLengthIAMRoleName, AlwaysAddHash: false})
+
 	for j := 0; j < i.zones; j++ {
 		zone := "us-test-1" + string([]byte{byte('a') + byte(j)})
 		expectedFilenames = append(expectedFilenames,
@@ -1099,10 +1135,10 @@ func (i *integrationTest) runTestTerraformAWS(t *testing.T) {
 
 	if i.expectPolicies {
 		expectedFilenames = append(expectedFilenames, []string{
-			"aws_iam_role_masters." + i.clusterName + "_policy",
-			"aws_iam_role_nodes." + i.clusterName + "_policy",
-			"aws_iam_role_policy_masters." + i.clusterName + "_policy",
-			"aws_iam_role_policy_nodes." + i.clusterName + "_policy",
+			"aws_iam_role_" + masterRole + "_policy",
+			"aws_iam_role_" + nodeRole + "_policy",
+			"aws_iam_role_policy_" + masterRole + "_policy",
+			"aws_iam_role_policy_" + nodeRole + "_policy",
 		}...)
 		if i.private {
 			expectedFilenames = append(expectedFilenames, []string{
