@@ -53,6 +53,7 @@ type Policy struct {
 	clusterTaggedAction       sets.String
 	clusterTaggedCreateAction sets.String
 	Statement                 []*Statement
+	partition                 string
 	Version                   string
 }
 
@@ -60,14 +61,14 @@ func (p *Policy) AddUnconditionalActions(actions ...string) {
 	p.unconditionalAction.Insert(actions...)
 }
 
-func (p *Policy) AddEC2CreateAction(actions, resources []string, partition string) {
+func (p *Policy) AddEC2CreateAction(actions, resources []string) {
 	actualActions := []string{}
 	for _, action := range actions {
 		actualActions = append(actualActions, "ec2:"+action)
 	}
 	actualResources := []string{}
 	for _, resource := range resources {
-		actualResources = append(actualResources, fmt.Sprintf("arn:%s:ec2:*:*:%s/*", partition, resource))
+		actualResources = append(actualResources, fmt.Sprintf("arn:%s:ec2:*:*:%s/*", p.partition, resource))
 	}
 
 	p.clusterTaggedCreateAction.Insert(actualActions...)
@@ -136,6 +137,15 @@ func (p *Policy) AsJSON() (string, error) {
 				},
 			},
 		})
+		// ec2:CreateSecurityGroup needs some special care as it also interacts with vpc, which do not support RequestTag.
+		// We also do not require VPCs to be tagged, so we are not sending any conditions, allowing SGs to be created in any VPC.
+		if p.clusterTaggedCreateAction.Has("ec2:CreateSecurityGroup") {
+			p.Statement = append(p.Statement, &Statement{
+				Effect:   StatementEffectAllow,
+				Action:   stringorslice.Of("ec2:CreateSecurityGroup"),
+				Resource: stringorslice.String(fmt.Sprintf("arn:%s:ec2:*:*:vpc/*", p.partition)),
+			})
+		}
 	}
 	if len(p.Statement) == 0 {
 		return "", fmt.Errorf("policy contains no statement")
@@ -323,20 +333,21 @@ func (b *PolicyBuilder) BuildAWSPolicy() (*Policy, error) {
 	return p, nil
 }
 
-func NewPolicy(clusterName string) *Policy {
+func NewPolicy(clusterName, partition string) *Policy {
 	p := &Policy{
 		Version:                   PolicyDefaultVersion,
 		clusterName:               clusterName,
 		unconditionalAction:       sets.NewString(),
 		clusterTaggedAction:       sets.NewString(),
 		clusterTaggedCreateAction: sets.NewString(),
+		partition:                 partition,
 	}
 	return p
 }
 
 // BuildAWSPolicy generates a custom policy for a Kubernetes master.
 func (r *NodeRoleAPIServer) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
-	p := NewPolicy(b.Cluster.GetName())
+	p := NewPolicy(b.Cluster.GetName(), b.Partition)
 
 	b.addNodeupPermissions(p, r.warmPool)
 
@@ -354,7 +365,7 @@ func (r *NodeRoleAPIServer) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	}
 
 	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.AmazonVPC != nil {
-		addAmazonVPCCNIPermissions(p, b.Partition)
+		addAmazonVPCCNIPermissions(p)
 	}
 
 	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil && b.Cluster.Spec.Networking.Cilium.IPAM == kops.CiliumIpamEni {
@@ -372,7 +383,7 @@ func (r *NodeRoleAPIServer) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	clusterName := b.Cluster.GetName()
 
-	p := NewPolicy(clusterName)
+	p := NewPolicy(clusterName, b.Partition)
 
 	addEtcdManagerPermissions(p)
 	b.addNodeupPermissions(p, false)
@@ -395,18 +406,21 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 
 	// If cluster does not use external CCM, the master IAM Role needs CCM permissions
 	if b.Cluster.Spec.ExternalCloudControllerManager == nil {
-		AddCCMPermissions(p, b.Partition, b.Cluster.Spec.Networking.Kubenet != nil)
+		AddCCMPermissions(p, b.Cluster.Spec.Networking.Kubenet != nil)
 		AddLegacyCCMPermissions(p)
 	}
 
 	if !b.UseServiceAccountExternalPermisssions {
 		esc := b.Cluster.Spec.SnapshotController != nil &&
 			fi.BoolValue(b.Cluster.Spec.SnapshotController.Enabled)
-		AddAWSEBSCSIDriverPermissions(p, b.Partition, esc)
+		AddAWSEBSCSIDriverPermissions(p, esc)
 
 		if b.Cluster.Spec.ExternalCloudControllerManager != nil {
-			AddCCMPermissions(p, b.Partition, b.Cluster.Spec.Networking.Kubenet != nil)
-			AddLegacyCCMPermissions(p)
+			AddCCMPermissions(p, b.Cluster.Spec.Networking.Kubenet != nil)
+
+			if b.Cluster.IsKubernetesLT("1.23") {
+				AddLegacyCCMPermissions(p)
+			}
 		}
 
 		if b.Cluster.Spec.AWSLoadBalancerController != nil && fi.BoolValue(b.Cluster.Spec.AWSLoadBalancerController.Enabled) {
@@ -425,7 +439,7 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	}
 
 	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.AmazonVPC != nil {
-		addAmazonVPCCNIPermissions(p, b.Partition)
+		addAmazonVPCCNIPermissions(p)
 	}
 
 	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Cilium != nil && b.Cluster.Spec.Networking.Cilium.IPAM == kops.CiliumIpamEni {
@@ -441,7 +455,7 @@ func (r *NodeRoleMaster) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 
 // BuildAWSPolicy generates a custom policy for a Kubernetes node.
 func (r *NodeRoleNode) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
-	p := NewPolicy(b.Cluster.GetName())
+	p := NewPolicy(b.Cluster.GetName(), b.Partition)
 
 	b.addNodeupPermissions(p, r.enableLifecycleHookPermissions)
 
@@ -455,7 +469,7 @@ func (r *NodeRoleNode) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 	}
 
 	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.AmazonVPC != nil {
-		addAmazonVPCCNIPermissions(p, b.Partition)
+		addAmazonVPCCNIPermissions(p)
 	}
 
 	if b.Cluster.Spec.Networking != nil && b.Cluster.Spec.Networking.Calico != nil && b.Cluster.Spec.Networking.Calico.AWSSrcDstCheck != "DoNothing" {
@@ -467,7 +481,7 @@ func (r *NodeRoleNode) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
 
 // BuildAWSPolicy generates a custom policy for a bastion host.
 func (r *NodeRoleBastion) BuildAWSPolicy(b *PolicyBuilder) (*Policy, error) {
-	p := NewPolicy(b.Cluster.GetName())
+	p := NewPolicy(b.Cluster.GetName(), b.Partition)
 
 	// Bastion hosts currently don't require any specific permissions.
 	// A trivial permission is granted, because empty policies are not allowed.
@@ -598,7 +612,7 @@ func (b *PolicyBuilder) AddS3Permissions(p *Policy) (*Policy, error) {
 				"s3:ListBucketVersions",
 			),
 			Resource: stringorslice.Slice([]string{
-				fmt.Sprintf("arn:%v:s3:::%v", b.Partition, s3Bucket),
+				fmt.Sprintf("arn:%v:s3:::%v", p.partition, s3Bucket),
 			}),
 		})
 	}
@@ -616,7 +630,7 @@ func (b *PolicyBuilder) buildS3WriteStatements(p *Policy, iamS3Path string) {
 			"s3:PutObject",
 		}),
 		Resource: stringorslice.Of(
-			fmt.Sprintf("arn:%v:s3:::%v/*", b.Partition, iamS3Path),
+			fmt.Sprintf("arn:%v:s3:::%v/*", p.partition, iamS3Path),
 		),
 	})
 }
@@ -632,7 +646,7 @@ func (b *PolicyBuilder) buildS3GetStatements(p *Policy, iamS3Path string) error
 
 		// Add the prefix for IAM
 		for i, r := range resources {
-			resources[i] = fmt.Sprintf("arn:%v:s3:::%v%v", b.Partition, iamS3Path, r)
+			resources[i] = fmt.Sprintf("arn:%v:s3:::%v%v", p.partition, iamS3Path, r)
 		}
 
 		p.Statement = append(p.Statement, &Statement{
@@ -856,10 +870,19 @@ func AddLegacyCCMPermissions(p *Policy) {
 		"elasticloadbalancing:CreateListener",
 		"elasticloadbalancing:DeleteListener",
 		"elasticloadbalancing:ModifyListener",
+		"ec2:DescribeVolumes",
+		"ec2:ModifyInstanceAttribute",
+		"ec2:ModifyVolume",
+		"ec2:AttachVolume",
+		"ec2:AuthorizeSecurityGroupIngress",
+		"ec2:DeleteRoute",
+		"ec2:DeleteSecurityGroup",
+		"ec2:DeleteVolume",
+		"ec2:DetachVolume",
 	)
 }
 
-func AddCCMPermissions(p *Policy, partition string, cloudRoutes bool) {
+func AddCCMPermissions(p *Policy, cloudRoutes bool) {
 	p.unconditionalAction.Insert(
 		"autoscaling:DescribeAutoScalingGroups",
 		"autoscaling:DescribeTags",
@@ -868,7 +891,6 @@ func AddCCMPermissions(p *Policy, partition string, cloudRoutes bool) {
 		"ec2:DescribeRouteTables",
 		"ec2:DescribeSecurityGroups",
 		"ec2:DescribeSubnets",
-		"ec2:DescribeVolumes",
 		"ec2:DescribeVpcs",
 		"elasticloadbalancing:DescribeLoadBalancers",
 		"elasticloadbalancing:DescribeLoadBalancerAttributes",
@@ -881,15 +903,9 @@ func AddCCMPermissions(p *Policy, partition string, cloudRoutes bool) {
 
 	p.clusterTaggedAction.Insert(
 		"ec2:ModifyInstanceAttribute",
-		"ec2:ModifyVolume",
-		"ec2:AttachVolume",
 		"ec2:AuthorizeSecurityGroupIngress",
-		"ec2:DeleteRoute",
 		"ec2:DeleteSecurityGroup",
-		"ec2:DeleteVolume",
-		"ec2:DetachVolume",
 		"ec2:RevokeSecurityGroupIngress",
-		"elasticloadbalancing:AddTags",
 		"elasticloadbalancing:AttachLoadBalancerToSubnets",
 		"elasticloadbalancing:ApplySecurityGroupsToLoadBalancer",
 		"elasticloadbalancing:CreateLoadBalancerListeners",
@@ -912,34 +928,19 @@ func AddCCMPermissions(p *Policy, partition string, cloudRoutes bool) {
 
 	p.clusterTaggedCreateAction.Insert(
 		"elasticloadbalancing:CreateLoadBalancer",
-		"ec2:CreateSecurityGroup",
-		"ec2:CreateVolume",
 		"elasticloadbalancing:CreateListener",
 		"elasticloadbalancing:CreateTargetGroup",
 	)
 
-	p.Statement = append(p.Statement,
-		&Statement{
-			Effect: StatementEffectAllow,
-			Action: stringorslice.Of(
-				"ec2:CreateTags",
-			),
-			Resource: stringorslice.Slice(
-				[]string{
-					fmt.Sprintf("arn:%v:ec2:*:*:volume/*", partition),
-					fmt.Sprintf("arn:%v:ec2:*:*:snapshot/*", partition),
-				},
-			),
-			Condition: Condition{
-				"StringEquals": map[string]interface{}{
-					"ec2:CreateAction": []string{
-						"CreateVolume",
-						"CreateSnapshot",
-					},
-				},
-			},
+	p.AddEC2CreateAction(
+		[]string{
+			"CreateSecurityGroup",
+		},
+		[]string{
+			"security-group",
 		},
 	)
+
 	if cloudRoutes {
 		p.clusterTaggedAction.Insert(
 			"ec2:CreateRoute",
@@ -984,6 +985,8 @@ func AddAWSLoadbalancerControllerPermissions(p *Policy, partition string) {
 		"elasticloadbalancing:DeleteTargetGroup",
 		"elasticloadbalancing:DeleteRule",
 		"elasticloadbalancing:DeregisterTargets",
+		"elasticloadbalancing:ModifyLoadBalancerAttributes",
+		"elasticloadbalancing:ModifyListener",
 		"elasticloadbalancing:ModifyRule",
 		"elasticloadbalancing:ModifyTargetGroup",
 		"elasticloadbalancing:ModifyTargetGroupAttributes",
@@ -1006,7 +1009,6 @@ func AddAWSLoadbalancerControllerPermissions(p *Policy, partition string) {
 		[]string{
 			"security-group",
 		},
-		partition,
 	)
 }
 
@@ -1024,7 +1026,7 @@ func AddClusterAutoscalerPermissions(p *Policy) {
 }
 
 // AddAWSEBSCSIDriverPermissions appens policy statements that the AWS EBS CSI Driver needs to operate.
-func AddAWSEBSCSIDriverPermissions(p *Policy, partition string, appendSnapshotPermissions bool) {
+func AddAWSEBSCSIDriverPermissions(p *Policy, appendSnapshotPermissions bool) {
 	if appendSnapshotPermissions {
 		addSnapshotPersmissions(p)
 	}
@@ -1053,7 +1055,6 @@ func AddAWSEBSCSIDriverPermissions(p *Policy, partition string, appendSnapshotPe
 			"volume",
 			"snapshot",
 		},
-		partition,
 	)
 }
 
@@ -1161,7 +1162,7 @@ func addCiliumEniPermissions(p *Policy) {
 	)
 }
 
-func addAmazonVPCCNIPermissions(p *Policy, partition string) {
+func addAmazonVPCCNIPermissions(p *Policy) {
 	p.unconditionalAction.Insert(
 		"ec2:AssignPrivateIpAddresses",
 		"ec2:AttachNetworkInterface",
@@ -1183,7 +1184,7 @@ func addAmazonVPCCNIPermissions(p *Policy, partition string) {
 				"ec2:CreateTags",
 			}),
 			Resource: stringorslice.Slice([]string{
-				strings.Join([]string{"arn:", partition, ":ec2:*:*:network-interface/*"}, ""),
+				strings.Join([]string{"arn:", p.partition, ":ec2:*:*:network-interface/*"}, ""),
 			}),
 		},
 	)
