@@ -21,12 +21,14 @@ import (
 	"fmt"
 	"net"
 	"net/url"
+	"sort"
 	"strings"
 
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/client-go/tools/pager"
 	"k8s.io/kops/pkg/apis/kops"
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/kops/upup/pkg/fi/cloudup"
 
 	v1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -79,23 +81,24 @@ type ValidationNode struct {
 }
 
 // hasPlaceHolderIP checks if the API DNS has been updated.
-func hasPlaceHolderIP(host string) (bool, error) {
+func hasPlaceHolderIP(host string) (string, error) {
 	apiAddr, err := url.Parse(host)
 	if err != nil {
-		return true, fmt.Errorf("unable to parse Kubernetes cluster API URL: %v", err)
+		return "", fmt.Errorf("unable to parse Kubernetes cluster API URL: %v", err)
 	}
 	hostAddrs, err := net.LookupHost(apiAddr.Hostname())
 	if err != nil {
-		return true, fmt.Errorf("unable to resolve Kubernetes cluster API URL dns: %v", err)
+		return "", fmt.Errorf("unable to resolve Kubernetes cluster API URL dns: %v", err)
 	}
 
+	sort.Strings(hostAddrs)
 	for _, h := range hostAddrs {
-		if h == "203.0.113.123" {
-			return true, nil
+		if h == cloudup.PlaceholderIP || h == cloudup.PlaceholderIPv6 {
+			return h, nil
 		}
 	}
 
-	return false, nil
+	return "", nil
 }
 
 func NewClusterValidator(cluster *kops.Cluster, cloud fi.Cloud, instanceGroupList *kops.InstanceGroupList, host string, k8sClient kubernetes.Interface) (ClusterValidator, error) {
@@ -123,6 +126,10 @@ func (v *clusterValidatorImpl) Validate() (*ValidationCluster, error) {
 	ctx := context.TODO()
 
 	clusterName := v.cluster.Name
+	dnsProvider := kops.ExternalDNSProviderDNSController
+	if v.cluster.Spec.ExternalDNS != nil && v.cluster.Spec.ExternalDNS.Provider == kops.ExternalDNSProviderExternalDNS {
+		dnsProvider = kops.ExternalDNSProviderExternalDNS
+	}
 
 	validation := &ValidationCluster{}
 
@@ -133,13 +140,13 @@ func (v *clusterValidatorImpl) Validate() (*ValidationCluster, error) {
 			return nil, err
 		}
 
-		if hasPlaceHolderIPAddress {
-			message := "Validation Failed\n\n" +
-				"The dns-controller Kubernetes deployment has not updated the Kubernetes cluster's API DNS entry to the correct IP address." +
-				"  The API DNS IP address is the placeholder address that kops creates: 203.0.113.123." +
-				"  Please wait about 5-10 minutes for a master to start, dns-controller to launch, and DNS to propagate." +
-				"  The protokube container and dns-controller deployment logs may contain more diagnostic information." +
-				"  Etcd and the API DNS entries must be updated for a kops Kubernetes cluster to start."
+		if hasPlaceHolderIPAddress != "" {
+			message := fmt.Sprintf("Validation Failed\n\n"+
+				"The %[1]v Kubernetes deployment has not updated the Kubernetes cluster's API DNS entry to the correct IP address."+
+				"  The API DNS IP address is the placeholder address that kops creates: %[2]v."+
+				"  Please wait about 5-10 minutes for a master to start, %[1]v to launch, and DNS to propagate."+
+				"  The protokube container and %[1]v deployment logs may contain more diagnostic information."+
+				"  Etcd and the API DNS entries must be updated for a kops Kubernetes cluster to start.", dnsProvider, hasPlaceHolderIPAddress)
 			validation.addError(&ValidationError{
 				Kind:    "dns",
 				Name:    "apiserver",
