@@ -28,6 +28,7 @@ import (
 	"github.com/digitalocean/godo"
 	"golang.org/x/oauth2"
 	v1 "k8s.io/api/core/v1"
+	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/klog/v2"
 	"k8s.io/kops/dnsprovider/pkg/dnsprovider"
 	dns "k8s.io/kops/dnsprovider/pkg/dnsprovider/providers/do"
@@ -35,6 +36,7 @@ import (
 	"k8s.io/kops/pkg/cloudinstances"
 	"k8s.io/kops/protokube/pkg/etcd"
 	"k8s.io/kops/upup/pkg/fi"
+	"k8s.io/kops/util/pkg/vfs"
 )
 
 const (
@@ -68,10 +70,20 @@ type DOCloud interface {
 	LoadBalancersService() godo.LoadBalancersService
 	DomainService() godo.DomainsService
 	ActionsService() godo.ActionsService
+	VPCsService() godo.VPCsService
 	FindClusterStatus(cluster *kops.Cluster) (*kops.ClusterStatus, error)
 	GetAllLoadBalancers() ([]godo.LoadBalancer, error)
 	GetAllDropletsByTag(tag string) ([]godo.Droplet, error)
 	GetAllVolumesByRegion() ([]godo.Volume, error)
+	GetVPCUUID(networkCIDR string, vpcName string) (string, error)
+	GetAllVPCs() ([]*godo.VPC, error)
+}
+
+var readBackoff = wait.Backoff{
+	Duration: time.Second,
+	Factor:   2,
+	Jitter:   0.1,
+	Steps:    10,
 }
 
 // static compile time check to validate DOCloud's fi.Cloud Interface.
@@ -223,41 +235,81 @@ func (c *doCloudImplementation) ActionsService() godo.ActionsService {
 	return c.Client.Actions
 }
 
+func (c *doCloudImplementation) VPCsService() godo.VPCsService {
+	return c.Client.VPCs
+}
+
 // FindVPCInfo is not implemented, it's only here to satisfy the fi.Cloud interface
 func (c *doCloudImplementation) FindVPCInfo(id string) (*fi.VPCInfo, error) {
 	return nil, errors.New("not implemented")
 }
 
-func (c *doCloudImplementation) GetApiIngressStatus(cluster *kops.Cluster) ([]fi.ApiIngressStatus, error) {
-	var ingresses []fi.ApiIngressStatus
-	if cluster.Spec.MasterPublicName != "" {
-		// Note that this must match Digital Ocean's lb name
-		klog.V(2).Infof("Querying DO to find Loadbalancers for API (%q)", cluster.Name)
-
-		loadBalancers, err := c.GetAllLoadBalancers()
+func (c *doCloudImplementation) GetVPCUUID(networkCIDR string, vpcName string) (string, error) {
+	vpcUUID := ""
+	done, err := vfs.RetryWithBackoff(readBackoff, func() (bool, error) {
+		vpcs, err := c.GetAllVPCs()
 		if err != nil {
-			return nil, fmt.Errorf("LoadBalancers.List returned error: %v", err)
+			return false, err
 		}
 
-		lbName := "api-" + strings.Replace(cluster.Name, ".", "-", -1)
-
-		for _, lb := range loadBalancers {
-			if lb.Name == lbName {
-				klog.V(10).Infof("Matching LB name found for API (%q)", cluster.Name)
-
-				if lb.Status != "active" {
-					return nil, fmt.Errorf("load-balancer is not yet active (current status: %s)", lb.Status)
-				}
-
-				address := lb.IP
-				ingresses = append(ingresses, fi.ApiIngressStatus{IP: address})
-
-				return ingresses, nil
+		for _, vpc := range vpcs {
+			if vpc.IPRange == networkCIDR && vpc.Name == vpcName {
+				vpcUUID = vpc.ID
+				return true, nil
 			}
 		}
+
+		return false, fmt.Errorf("vpc not yet created..")
+	})
+
+	if err != nil {
+		return "", err
 	}
 
-	return nil, nil
+	if done {
+		return vpcUUID, nil
+	} else {
+		return "", wait.ErrWaitTimeout
+	}
+}
+
+func (c *doCloudImplementation) GetApiIngressStatus(cluster *kops.Cluster) ([]fi.ApiIngressStatus, error) {
+	var ingresses []fi.ApiIngressStatus
+	done, err := vfs.RetryWithBackoff(readBackoff, func() (bool, error) {
+		if cluster.Spec.MasterPublicName != "" {
+			// Note that this must match Digital Ocean's lb name
+			klog.V(2).Infof("Querying DO to find Loadbalancers for API (%q)", cluster.Name)
+
+			loadBalancers, err := c.GetAllLoadBalancers()
+			if err != nil {
+				return false, fmt.Errorf("LoadBalancers.List returned error: %v", err)
+			}
+
+			lbName := "api-" + strings.Replace(cluster.Name, ".", "-", -1)
+
+			for _, lb := range loadBalancers {
+				if lb.Name == lbName {
+					klog.V(10).Infof("Matching LB name found for API (%q)", cluster.Name)
+
+					if lb.Status != "active" {
+						return false, fmt.Errorf("load-balancer is not yet active (current status: %s)", lb.Status)
+					}
+
+					address := lb.IP
+					ingresses = append(ingresses, fi.ApiIngressStatus{IP: address})
+				}
+			}
+		}
+		return true, nil
+	})
+	if done {
+		return ingresses, nil
+	} else {
+		if err == nil {
+			err = wait.ErrWaitTimeout
+		}
+		return ingresses, err
+	}
 }
 
 // FindClusterStatus discovers the status of the cluster, by looking for the tagged etcd volumes
@@ -321,7 +373,7 @@ func findEtcdStatus(c *doCloudImplementation, cluster *kops.Cluster) ([]kops.Etc
 						memberName := etcdClusterSpec.NodeName
 						status.Members = append(status.Members, &kops.EtcdMemberStatus{
 							Name:     memberName,
-							VolumeId: volume.ID,
+							VolumeID: volume.ID,
 						})
 					}
 				}
@@ -510,6 +562,33 @@ func (c *doCloudImplementation) GetAllLoadBalancers() ([]godo.LoadBalancer, erro
 	return allLoadBalancers, nil
 }
 
+func (c *doCloudImplementation) GetAllVPCs() ([]*godo.VPC, error) {
+	allVPCs := []*godo.VPC{}
+
+	opt := &godo.ListOptions{}
+	for {
+		vpcs, resp, err := c.VPCsService().List(context.TODO(), opt)
+		if err != nil {
+			return nil, err
+		}
+
+		allVPCs = append(allVPCs, vpcs...)
+
+		if resp.Links == nil || resp.Links.IsLastPage() {
+			break
+		}
+
+		page, err := resp.Links.CurrentPage()
+		if err != nil {
+			return nil, err
+		}
+
+		opt.Page = page + 1
+	}
+
+	return allVPCs, nil
+}
+
 func (c *doCloudImplementation) GetAllDropletsByTag(tag string) ([]godo.Droplet, error) {
 	allDroplets := []godo.Droplet{}
 
