@@ -18,14 +18,12 @@ package cloudup
 
 import (
 	"fmt"
-	"sort"
 	"strings"
 
 	"k8s.io/klog/v2"
 	"k8s.io/kops/dnsprovider/pkg/dnsprovider"
 	"k8s.io/kops/dnsprovider/pkg/dnsprovider/providers/aws/route53"
 	"k8s.io/kops/pkg/apis/kops"
-	"k8s.io/kops/pkg/featureflag"
 	"k8s.io/kops/upup/pkg/fi"
 	"k8s.io/kops/upup/pkg/fi/cloudup/aliup"
 	"k8s.io/kops/upup/pkg/fi/cloudup/awsup"
@@ -170,26 +168,6 @@ func BuildCloud(cluster *kops.Cluster) (fi.Cloud, error) {
 	return cloud, nil
 }
 
-func SupportedClouds() []string {
-	clouds := []string{
-		string(kops.CloudProviderAWS),
-		string(kops.CloudProviderDO),
-		string(kops.CloudProviderOpenstack),
-	}
-	if featureflag.AlphaAllowALI.Enabled() {
-		clouds = append(clouds, string(kops.CloudProviderALI))
-	}
-	if featureflag.Azure.Enabled() {
-		clouds = append(clouds, string(kops.CloudProviderAzure))
-	}
-	if featureflag.AlphaAllowGCE.Enabled() {
-		clouds = append(clouds, string(kops.CloudProviderGCE))
-	}
-
-	sort.Strings(clouds)
-	return clouds
-}
-
 func FindDNSHostedZone(dns dnsprovider.Interface, clusterDNSName string, dnsType kops.DNSType) (string, error) {
 	klog.V(2).Infof("Querying for all DNS zones to find match for %q", clusterDNSName)
 
